@@ -617,27 +617,30 @@ class QueryBuilder:
         try:
             # Build group_id with proper field expressions
             group_id = {}
+            project_fields = {}
+
             for field in distinct_params:
                 try:
                     # Use utility function to build proper aggregation expression
                     field_expression = build_aggregation_field_expression(field)
 
-                    # Create nested structure for fields with dot notation
-                    parts = field.split(".")
-                    d = group_id
-                    for i, part in enumerate(parts[:-1]):
-                        # If a non-dict value is at the path, it can't be extended
-                        if part in d and not isinstance(d[part], dict):
-                            # To avoid overwriting, you could add a unique suffix, or handle as an error
-                            # For now, let's just print a warning and continue
-                            print(
-                                f"Warning: conflicting path in distinct fields for '{field}' at part '{part}'."
-                            )
-                            d = d.setdefault(f"{part}_{i}", {})
-                        else:
-                            d = d.setdefault(part, {})
+                    # For MongoDB $group stage, we need to use a safe key name (no dots)
+                    # We'll use the original field name as key, but replace dots with underscores for the group
+                    safe_key = (
+                        field.replace(".", "_").replace("[", "_").replace("]", "_")
+                    )
+                    group_id[safe_key] = field_expression
 
-                    d[parts[-1]] = field_expression
+                    # Build nested structure for the projection to maintain original field structure
+                    parts = field.split(".")
+                    current = project_fields
+                    for i, part in enumerate(parts[:-1]):
+                        if part not in current:
+                            current[part] = {}
+                        current = current[part]
+
+                    # Set the final value
+                    current[parts[-1]] = f"$_id.{safe_key}"
 
                 except ValueError as e:
                     # Log error and skip invalid field
@@ -650,8 +653,9 @@ class QueryBuilder:
             group_stage = {"$group": {"_id": group_id}}
 
             if include_project:
-                replace_root_stage = {"$replaceRoot": {"newRoot": "$_id"}}
-                return [group_stage, replace_root_stage]
+                # Use $project to create the nested structure
+                project_stage = {"$project": project_fields}
+                return [group_stage, project_stage]
             else:
                 return [group_stage]
 
